@@ -12,7 +12,7 @@ maintaining the widget state and invoking callbacks, all aspects
 of the widgets appearance lies at Themes.
 """
 
-__version__ = "0.2"
+__version__ = "0.2.5"
 
 __author__ = "Guilherme Polo <ggpolo@gmail.com>"
 
@@ -360,7 +360,8 @@ class Style(object):
                 Tkinter._default_root = Tkinter.Tk()
             master = Tkinter._default_root
 
-        self.tk = master.tk
+        self.master = master
+        self.tk = self.master.tk
 
 
     def configure(self, style, query_opt=None, **kw):
@@ -552,15 +553,15 @@ class Widget(Tkinter.Widget):
     def instate(self, statespec, callback=None, *args, **kw):
         """Test the widget's state.
 
-        If callback is not specified, returns 1 if the widget state
-        matches statespec and 0 otherwise. If callback is specified,
+        If callback is not specified, returns True if the widget state
+        matches statespec and False otherwise. If callback is specified,
         then it will be invoked with *args, **kw if the widget state
         matches statespec. statespec is expected to be a sequence."""
         ret = self.tk.call(self._w, "instate", ' '.join(statespec))
         if ret and callback:
             return callback(*args, **kw)
 
-        return ret
+        return bool(ret)
 
 
     def state(self, statespec=None):
@@ -570,10 +571,10 @@ class Widget(Tkinter.Widget):
         set according to the statespec flags and then a new state spec
         is returned indicating which flags were changed. statespec is
         expected to be a sequence."""
-        statespec = statespec or ''
+        if statespec is not None:
+            statespec = ' '.join(statespec)
 
-        return self.tk.splitlist(
-            str(self.tk.call(self._w, "state", ' '.join(statespec))))
+        return self.tk.splitlist(str(self.tk.call(self._w, "state", statespec)))
 
 
 class Button(Widget):
@@ -666,9 +667,9 @@ class Entry(Widget, Tkinter.Entry):
 
     def validate(self):
         """Force revalidation, independent of the conditions specified
-        by the validate option. Returns 0 if validation fails, 1 if it
-        succeeds. Sets or clears the invalid state accordingly."""
-        return self.tk.call(self._w, "validate")
+        by the validate option. Returns False if validation fails, True
+        if it succeeds. Sets or clears the invalid state accordingly."""
+        return bool(self.tk.call(self._w, "validate"))
 
 
 class Combobox(Entry):
@@ -687,9 +688,31 @@ class Combobox(Entry):
             exportselection, justify, height, postcommand, state,
             textvariable, values, width
         """
+        if "values" in kw:
+            # may need special formatting if any value is an empty string
+            kw["values"] = _format_optdict({'v': kw["values"]})[1]
+
         Entry.__init__(self, master, "ttk::combobox", **kw)
 
 
+    def __setitem__(self, item, value):
+        if item == "values":
+            # may need special formatting if any value is an empty string
+            value = _format_optdict({item: value})[1]
+
+        Entry.__setitem__(self, item, value)
+
+
+    def configure(self, cnf=None, **kw):
+        """Custom Combobox configure, created to properly format the values
+        option."""
+        if "values" in kw:
+            # may need special formatting if any value is an empty string
+            kw["values"] = _format_optdict({'v': kw["values"]})[1]
+
+        return Entry.configure(self, cnf, **kw)
+
+
     def current(self, newindex=None):
         """If newindex is supplied, sets the combobox value to the
         element at position newindex in the list of values. Otherwise,
@@ -882,7 +905,7 @@ class Notebook(Widget):
 
     def tabs(self):
         """Returns a list of windows managed by the notebook."""
-        return self.tk.call(self._w, "tabs")
+        return self.tk.call(self._w, "tabs") or ()
 
 
     def enable_traversal(self):
@@ -933,6 +956,9 @@ class Panedwindow(Widget, Tkinter.PanedWindow):
         Widget.__init__(self, master, "ttk::panedwindow", kw)
 
 
+    forget = Tkinter.PanedWindow.forget # overrides Pack.forget
+
+
     def insert(self, pos, child, **kw):
         """Inserts a pane at the specified positions.
 
@@ -1053,11 +1079,13 @@ class Scale(Widget, Tkinter.Scale):
         Widget.__init__(self, master, "ttk::scale", kw)
 
 
-    def configure(self, **kw):
+    def configure(self, cnf=None, **kw):
         """Modify or query scale options.
 
-        Changing "from", "from_" or "to" options generates a
-        <<RangeChanged>> event."""
+        Setting a value for any of the "from", "from_" or "to" options
+        generates a <<RangeChanged>> event."""
+        if cnf:
+            kw.update(cnf)
         Widget.configure(self, **kw)
         if any(['from' in kw, 'from_' in kw, 'to' in kw]):
             self.event_generate('<<RangeChanged>>')
@@ -1474,13 +1502,14 @@ class LabeledScale(Frame, object):
         self.label.place(anchor='n' if label_side == 'top' else 's')
 
         # update the label as scale or variable changes
-        self._variable.trace_variable('w', self._adjust)
+        self.__tracecb = self._variable.trace_variable('w', self._adjust)
         self.bind('<Configure>', self._adjust)
         self.bind('<Map>', self._adjust)
 
 
     def destroy(self):
         """Destroy this widget and possibly its associated variable."""
+        self._variable.trace_vdelete('w', self.__tracecb)
         del self._variable
         Frame.destroy(self)
 
